@@ -214,7 +214,7 @@ class HgImplementation(M.RepositoryImplementation):
         return doc
 
     def log(self, revs=None, path=None, exclude=None, id_only=True, **kw):
-        path = path.strip('/') if path else None
+        path = path.strip('/').encode('utf-8') if path else None
         revs = ['%s:0' % r for r in revs or []]
         pats = ['path:%s' % path] if path else []
         exclude = exclude or []
